@@ -9,7 +9,7 @@ from syst3m.classes.color import color, symbol
 from syst3m.classes import defaults
 from syst3m.classes.env import env
 from syst3m.classes.disks import disks
-from syst3m.classes.restapi import restapi
+from syst3m.classes.restapi import restapi, RestAPI
 #from syst3m.classes.screen import screen
 #from syst3m.classes.keyboard import keyboard
 #from syst3m.classes.mouse import mouse
\ No newline at end of file
