@@ -114,7 +114,7 @@ class WebServer(objects.Thread):
 			response = self.__serialize__(response.json())
 		except:
 			return r3sponse.error(f"Failed to serialize {response}: {response.text}")
-		return r3sponse.response(response, safe=True)
+		return r3sponse.response(response)
 	def get(self, group=None, id=None, timeout=3):
 		encoded = urllib.parse.urlencode({
 			"group":group.replace(" ","_"),
@@ -131,7 +131,7 @@ class WebServer(objects.Thread):
 			response = self.__serialize__(response.json())
 		except:
 			return r3sponse.error(f"Failed to serialize {response}: {response.text}")
-		return r3sponse.response(response, safe=True)
+		return r3sponse.response(response,)
 	# flask app.
 	def app(self):
 		app = flask.Flask(__name__)
