@@ -393,11 +393,14 @@ class OutputObject(ResponseObject):
 		attributes={},
 		# the error message (param #3).
 		error=None,
+		# the log level.
+		log_level=syst3m.defaults.options.log_level,
 	):
 		dictionary = {
 			"success":error == None,
 			"message":message,
 			"error":error,
+			"log_level":log_level,
 		}
 		for key,value in attributes.items():
 			dictionary[key] = value
@@ -408,6 +411,7 @@ class OutputObject(ResponseObject):
 			except AttributeError: self.output = ""
 		else: self.output = str(self.error) # keep this way for system functions.
 		self.lines = self.output.split("\n")
+		if self.log_level >= 0: print(self.output)
 
 	# representations.
 	def __len__(self):
@@ -561,18 +565,18 @@ def execute(
 	
 	# start.
 	response = spawn.start()
-	if not response.success: return OutputObject(error=f"Failed to start {response_str}, error: {response.error}")
+	if not response.success: return OutputObject(error=f"Failed to start {response_str}, error: {response.error}", log_level=log_level)
 	
 	# check crashed
 	response = spawn.crashed()
-	if not response.success:  return OutputObject(error=response.error)
+	if not response.success:  return OutputObject(error=response.error, log_level=log_level)
 
 	# has already exited.
 	elif spawn.exit_status in [0]:
 		
 		# get output.
 		response = spawn.wait(timeout=1.0)
-		if not response.success: return OutputObject(error=response.error) # exit status.
+		if not response.success: return OutputObject(error=response.error, log_level=log_level) # exit status.
 		output = response.output
 
 		#
@@ -584,7 +588,7 @@ def execute(
 		for i in range(10):
 			if spawn.running: break
 			time.sleep(1)
-		if not spawn.running: return OutputObject(error=f"Unable to start {response_str}.")
+		if not spawn.running: return OutputObject(error=f"Unable to start {response_str}.", log_level=log_level)
 
 		# str input.
 		if isinstance(input, (list, Array)):
@@ -631,9 +635,9 @@ def execute(
 				expecting = False
 				if not optional:
 					if log_level >= 1:
-						return OutputObject(error=f"Failed to send expected input {str_input} to {response_str}, child is not expecting any input [{spawn.child}].")
+						return OutputObject(error=f"Failed to send expected input {str_input} to {response_str}, child is not expecting any input [{spawn.child}].", log_level=log_level)
 					else:
-						return OutputObject(error=f"Failed to send expected input {str_input} to {response_str}, child is not expecting any input.")
+						return OutputObject(error=f"Failed to send expected input {str_input} to {response_str}, child is not expecting any input.", log_level=log_level)
 
 			# limit not expecting by optional.
 			if expecting:
@@ -654,7 +658,7 @@ def execute(
 									str_input = Array(list(_input_.keys())).string(joiner=", ")
 								else: 
 									str_input = f"[{_input_}]"
-								return OutputObject(error=f"Failed to send one of the expected input(s) {str_input}, error: {response.error}")
+								return OutputObject(error=f"Failed to send one of the expected input(s) {str_input}, error: {response.error}", log_level=log_level)
 
 				# send one of the keys (dict instance).
 				elif isinstance(input, (dict, Dictionary)):
@@ -662,13 +666,13 @@ def execute(
 					if not response.success: 
 						if "End of file" in response.error:
 							error_end_of_file = True
-						else: return OutputObject(error=f"Failed to send one of the expected input(s) {str_input}, error: {response.error}")
+						else: return OutputObject(error=f"Failed to send one of the expected input(s) {str_input}, error: {response.error}", log_level=log_level)
 
 				""" check no input left (does not work properly).
 				if not error_end_of_file and spawn.expecting:
 					try: after = spawn.child.after.decode()
 					except : after = spawn.child.after
-					return OutputObject(error=f"Failed to execute {response_str}, still expecting: [{after}].")
+					return OutputObject(error=f"Failed to execute {response_str}, still expecting: [{after}].", log_level=log_level)
 				"""
 			
 
@@ -678,23 +682,23 @@ def execute(
 
 			# check crashed.
 			response = spawn.crashed()
-			if not response.success:  return OutputObject(error=response.error)
+			if not response.success:  return OutputObject(error=response.error, log_level=log_level)
 
 			# always await sync.
 			response = spawn.wait()
-			if not response.success: return OutputObject(error=response.error)
+			if not response.success: return OutputObject(error=response.error, log_level=log_level)
 			output = response.output
 			if error_end_of_file != None and error_end_of_file: 
 				if log_level >= 1:
-					return OutputObject(error=f"Failed to send expected input {str_input} to {response_str} (#234343) (output: {output}) (child: {spawn.child}).")
+					return OutputObject(error=f"Failed to send expected input {str_input} to {response_str} (#234343) (output: {output}) (child: {spawn.child}).", log_level=log_level)
 				else:
-					return OutputObject(error=f"Failed to send expected input {str_input} to {response_str} (#234343) (output: {output}).")
+					return OutputObject(error=f"Failed to send expected input {str_input} to {response_str} (#234343) (output: {output}).", log_level=log_level)
 
 			# check kill.
 			if kill and spawn.running:
 				if log_level >= 8: print(f"Killing process {response_str}.")
 				response = spawn.kill()
-				if not response.success: return OutputObject(error=f"Failed to kill {response_str}, error: {response.error}")
+				if not response.success: return OutputObject(error=f"Failed to kill {response_str}, error: {response.error}", log_level=log_level)
 
 		# async.
 		elif async_:
@@ -702,26 +706,26 @@ def execute(
 			# check exit status.
 			response = spawn.read(wait=False)
 			if not response.success: 
-				if not response.success: return OutputObject(error=f"Failed to retrieve output from spawn {response_str}, error: {response.error}")
+				if not response.success: return OutputObject(error=f"Failed to retrieve output from spawn {response_str}, error: {response.error}", log_level=log_level)
 			if spawn.child.exitstatus not in [0, None]:
-				return OutputObject(error=f"{response_str} returned exit status: [{spawn.child.exitstatus}].")
+				return OutputObject(error=f"{response_str} returned exit status: [{spawn.child.exitstatus}].", log_level=log_level)
 
 			# await async.
 			if wait:
 
 				# await.
 				response = spawn.wait(wait=True)
-				if not response.success: return OutputObject(error=response.error) # exit status.
+				if not response.success: return OutputObject(error=response.error, log_level=log_level) # exit status.
 				output = response.output
 
 				if spawn.child.exitstatus not in [0, None]:
-					return OutputObject(error=f"{response_str} returned exit status: [{spawn.child.exitstatus}].")
+					return OutputObject(error=f"{response_str} returned exit status: [{spawn.child.exitstatus}].", log_level=log_level)
 				
 				# check kill.
 				if kill and spawn.running:
 					if log_level >= 8: print(f"Killing process {response_str}.")
 					response = spawn.kill()
-					if not response.success: return OutputObject(error=f"Failed to kill {response_str}, error: {response.error}")
+					if not response.success: return OutputObject(error=f"Failed to kill {response_str}, error: {response.error}", log_level=log_level)
 
 	# handler.
 	if delete: Files.delete(path)
@@ -729,10 +733,10 @@ def execute(
 		try: response = r3sponse.ResponseObject(json=output)
 		except Exception as e: 
 			if loader != None: loader.stop(success=False)
-			return OutputObject(error=f"Failed to serialize (output: {output}).")
+			return OutputObject(error=f"Failed to serialize (output: {output}).", log_level=log_level)
 		if not response.success: 
-			return OutputObject(error=f"Encoutered an error in the serialized response, error: {response.error}")
-	return OutputObject(message=f"Succesfully executed {response_str}.", attributes={
+			return OutputObject(error=f"Encoutered an error in the serialized response, error: {response.error}", log_level=log_level)
+	return OutputObject(message=f"Succesfully executed {response_str}.", log_level=log_level, attributes={
 		"output":output,
 		"process":spawn,
 		"pid":spawn.child.pid,
@@ -750,7 +754,7 @@ def execute(
 			proc = subprocess.Popen(
 				[executive, path] + arguments,
 				shell=shell,)
-			return OutputObject(message=f"Succesfully executed {response_str}.", attributes={
+			return OutputObject(message=f"Succesfully executed {response_str}.", log_level=log_level, attributes={
 				"output":"",
 				"process":proc,
 				"pid":proc.pid,
@@ -772,26 +776,26 @@ def execute(
 			if isinstance(error_, bytes): error_ = error_.decode()
 			if isinstance(output, bytes): output = output.decode()
 			if log_level <= 0:
-				return OutputObject(error=f"Failed to execute {response_str}, (exception: {exception}), (error: {error_}).")
+				return OutputObject(error=f"Failed to execute {response_str}, (exception: {exception}), (error: {error_}).", log_level=log_level)
 			else:
-				return OutputObject(error=f"Failed to execute {response_str}, (exception: {exception}), (output: {output}), (error: {error_}).")
+				return OutputObject(error=f"Failed to execute {response_str}, (exception: {exception}), (output: {output}), (error: {error_}).", log_level=log_level)
 		error_, output = proc.stderr, proc.stdout
 		if isinstance(error_, bytes): error_ = error_.decode()
 		if isinstance(output, bytes): output = output.decode()
 		if error_ != "":
 			if log_level <= 0:
-				return OutputObject(error=f"Failed to execute {response_str}, (error: {error_}).")
+				return OutputObject(error=f"Failed to execute {response_str}, (error: {error_}).", log_level=log_level)
 			else:
-				return OutputObject(error=f"Failed to execute {response_str}, (output: {output}), (error: {error_}).")
+				return OutputObject(error=f"Failed to execute {response_str}, (output: {output}), (error: {error_}).", log_level=log_level)
 		if len(output) > 0 and output[len(output)-1] == "\n": output = output[:-1]
 		if serialize:
 			try: response = r3sponse.ResponseObject(json=output)
 			except Exception as e: 
 				if loader != None: loader.stop(success=False)
-				return OutputObject(error=f"Failed to serialize (output: {output}).")
+				return OutputObject(error=f"Failed to serialize (output: {output}).", log_level=log_level)
 			return response
 		else:
-			return OutputObject(message=f"Succesfully executed {response_str}.", attributes={
+			return OutputObject(message=f"Succesfully executed {response_str}.", log_level=log_level, attributes={
 				"output":output,
 				"process":proc,
 				"pid":None,
