@@ -164,7 +164,7 @@ class Service(objects.Object):
 			command = command[:-3]
 			output = console.execute(command)
 			if not output.success: return output
-			elif str(output) in ["", "\n"]:
+			elif output.output in ["", "\n"]:
 				return r3sponse.success(f"Successfully started {self.id}.")
 			else:
 				return r3sponse.error(f"Failed to start {self.id}.")
@@ -177,7 +177,7 @@ class Service(objects.Object):
 			command = command[:-3]
 			output = console.execute(command)
 			if not output.success: return output
-			elif str(output) in ["", "\n"]:
+			elif output.output in ["", "\n"]:
 				return r3sponse.success(f"Successfully started {self.id}.")
 			else:
 				return r3sponse.error(f"Failed to start {self.id}.")
@@ -193,7 +193,7 @@ class Service(objects.Object):
 			command = command[:-3]
 			output = console.execute(command)
 			if not output.success: return output
-			elif str(output) in ["", "\n"]:
+			elif output.output in ["", "\n"]:
 				return r3sponse.success(f"Successfully stopped {self.id}")
 			else:
 				return r3sponse.error(f"Failed to stop {self.id}")
@@ -206,7 +206,7 @@ class Service(objects.Object):
 			command = command[:-3]
 			output = console.execute(command)
 			if not output.success: return output
-			elif str(output) in ["", "\n"]:
+			elif output.output in ["", "\n"]:
 				return r3sponse.success(f"Successfully stopped {self.id}")
 			else:
 				return r3sponse.error(f"Failed to stop {self.id}")
@@ -230,7 +230,7 @@ class Service(objects.Object):
 			command = command[:-3]
 			output = console.execute(command)
 			if not output.success: return output
-			elif str(output) in ["", "\n"]:
+			elif output.output in ["", "\n"]:
 				return r3sponse.success(f"Successfully restarted {self.id}")
 			else:
 				return r3sponse.error(f"Failed to restarted {self.id}")
@@ -244,7 +244,7 @@ class Service(objects.Object):
 			if not output.success: return output
 			else:
 				return r3sponse.success(f"Successfully retrieved the status of {self.id}",{
-					"status":str(output),
+					"status":output.output,
 				})
 
 		# systemd.
@@ -253,7 +253,7 @@ class Service(objects.Object):
 			if not output.success: return output
 			else:
 				return r3sponse.success(f"Successfully retrieved the status of {self.id}",{
-					"status":str(output),
+					"status":output.output,
 				})
 
 			#
